Author: jtn
Date: Mon Sep 12 23:00:28 2016
New Revision: 33787

URL: http://svn.gna.org/viewcvs/freeciv?rev=33787&view=rev
Log:
Fix references to non-existent ACTIVITY_COUNT in comments.

Modified:
    branches/S2_5/common/tile.h
    branches/S2_5/common/unit.c
    branches/S2_5/common/unit.h

Modified: branches/S2_5/common/tile.h
URL: 
http://svn.gna.org/viewcvs/freeciv/branches/S2_5/common/tile.h?rev=33787&r1=33786&r2=33787&view=diff
==============================================================================
--- branches/S2_5/common/tile.h (original)
+++ branches/S2_5/common/tile.h Mon Sep 12 23:00:28 2016
@@ -160,7 +160,7 @@
 enum known_type tile_get_known(const struct tile *ptile,
                              const struct player *pplayer);
 
-/* An arbitrary somewhat integer value.  Activity times are multiplied by
+/* A somewhat arbitrary integer value.  Activity times are multiplied by
  * this amount, and divided by them later before being used.  This may
  * help to avoid rounding errors; however it should probably be removed. */
 #define ACTIVITY_FACTOR 10

Modified: branches/S2_5/common/unit.c
URL: 
http://svn.gna.org/viewcvs/freeciv/branches/S2_5/common/unit.c?rev=33787&r1=33786&r2=33787&view=diff
==============================================================================
--- branches/S2_5/common/unit.h (original)
+++ branches/S2_5/common/unit.h Mon Sep 12 23:00:28 2016
@@ -143,7 +143,7 @@
   enum unit_activity activity;
 
   /* The amount of work that has been done on the current activity.  This
-   * is counted in turns but is multiplied by ACTIVITY_COUNT (which allows
+   * is counted in turns but is multiplied by ACTIVITY_FACTOR (which allows
    * fractional values in some cases). */
   int activity_count;
 


_______________________________________________
Freeciv-commits mailing list
Freeciv-commits@gna.org
https://mail.gna.org/listinfo/freeciv-commits

Reply via email to
--- branches/S2_5/common/unit.c (original)
+++ branches/S2_5/common/unit.c Mon Sep 12 23:00:28 2016
@@ -559,7 +559,7 @@
   effects).  Usually this is just used for settlers but the value is also
   used for military units doing fortify/pillage activities.
 
-  The speed is multiplied by ACTIVITY_COUNT.
+  The speed is multiplied by ACTIVITY_FACTOR.
 **************************************************************************/
 int get_activity_rate(const struct unit *punit)
 {
@@ -577,7 +577,7 @@
    * uninjured ones.  Note the value is never less than SINGLE_MOVE. */
   int move_rate = unit_type(punit)->move_rate;
 
   /* All settler actions are multiplied by ACTIVITY_COUNT. */
   return ACTIVITY_FACTOR
          * (float)vlevel->power_fact / 100
          * move_rate / SINGLE_MOVE;
@@ -587,7 +587,7 @@
   Returns the amount of work a unit does (will do) on an activity this
   turn.  Units that have no MP do no work.
 
-  The speed is multiplied by ACTIVITY_COUNT.
+  The speed is multiplied by ACTIVITY_FACTOR.
 **************************************************************************/
 int get_activity_rate_this_turn(const struct unit *punit)
 {
@@ -577,7 +577,7 @@
   int move_rate = unit_type(punit)->move_rate;
 
-  /* All settler actions are multiplied by ACTIVITY_COUNT. */
+  /* All settler actions are multiplied by ACTIVITY_FACTOR. */
   return ACTIVITY_FACTOR
          * (float)vlevel->power_fact / 100

Modified: branches/S2_5/common/unit.h
URL: 
http://svn.gna.org/viewcvs/freeciv/branches/S2_5/common/unit.h?rev=33787&r1=33786&r2=33787&view=diff
==============================================================================